@@ -1,18 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "contactprintthemepreview.h"
+#include "contactprintthemeeditor_debug.h"
 #include "contactprintthemeeditorutil.h"
-#include <KSharedConfig>
+#include <Akonadi/Contact/GrantleePrint>
 #include <KConfigGroup>
+#include <KContacts/VCardConverter>
+#include <KSharedConfig>
 #include <QHBoxLayout>
 #include <QWebEngineView>
-#include <KContacts/VCardConverter>
-#include <Akonadi/Contact/GrantleePrint>
-#include "contactprintthemeeditor_debug.h"
 
 ContactPrintThemePreview::ContactPrintThemePreview(const QString &projectDirectory, QWidget *parent)
     : GrantleeThemeEditor::PreviewWidget(parent)
@@ -42,13 +42,13 @@ void ContactPrintThemePreview::updateViewer()
 
 void ContactPrintThemePreview::createScreenShot(const QStringList &fileName)
 {
-    Q_UNUSED(fileName);
+    Q_UNUSED(fileName)
     qCWarning(CONTACTPRINTTHEMEEDITOR_LOG) << "Create screenshot not implemented yet";
 }
 
 void ContactPrintThemePreview::setThemePath(const QString &projectDirectory, const QString &mainPageFileName)
 {
-    Q_UNUSED(mainPageFileName);
+    Q_UNUSED(mainPageFileName)
     mThemePath = projectDirectory;
 }
 
