@@ -143,7 +143,7 @@ void ThemeEditorPage::installTheme(const QString &themePath)
     }
     const QString newPath = themePath + QLatin1Char('/') + mDesktopPage->themeName();
     mEditorPage->installTheme(newPath);
-    for (EditorPage *page : qAsConst(mExtraPage)) {
+    for (EditorPage *page : std::as_const(mExtraPage)) {
         page->installTheme(newPath);
     }
     mDesktopPage->installTheme(newPath);
@@ -194,7 +194,7 @@ void ThemeEditorPage::createZip(const QString &themeName, KZip *zip)
 {
     mEditorPage->createZip(themeName, zip);
 
-    for (EditorPage *page : qAsConst(mExtraPage)) {
+    for (EditorPage *page : std::as_const(mExtraPage)) {
         page->createZip(themeName, zip);
     }
     mDesktopPage->createZip(themeName, zip);
@@ -202,14 +202,17 @@ void ThemeEditorPage::createZip(const QString &themeName, KZip *zip)
 
 void ThemeEditorPage::addExtraPage()
 {
-    QString filename = QInputDialog::getText(this, i18n("Filename of extra page"), i18n("Filename:"));
-    if (!filename.trimmed().isEmpty()) {
-        if (!filename.endsWith(QLatin1String(".html")) && !filename.endsWith(QLatin1String(".css")) && !filename.endsWith(QLatin1String(".js"))) {
-            filename += QLatin1String(".html");
+    bool ok = false;
+    QString filename = QInputDialog::getText(this, i18n("Filename of extra page"), i18n("Filename:"), {}, {}, &ok);
+    if (ok) {
+        if (!filename.trimmed().isEmpty()) {
+            if (!filename.endsWith(QLatin1String(".html")) && !filename.endsWith(QLatin1String(".css")) && !filename.endsWith(QLatin1String(".js"))) {
+                filename += QLatin1String(".html");
+            }
+            createExtraPage(filename);
+            mThemeSession->addExtraPage(filename);
+            setChanged(true);
         }
-        createExtraPage(filename);
-        mThemeSession->addExtraPage(filename);
-        setChanged(true);
     }
 }
 
@@ -229,7 +232,7 @@ void ThemeEditorPage::storeTheme(const QString &directory)
     const QString themeDirectory = directory.isEmpty() ? projectDirectory() : directory;
     mEditorPage->saveTheme(themeDirectory);
 
-    for (EditorPage *page : qAsConst(mExtraPage)) {
+    for (EditorPage *page : std::as_const(mExtraPage)) {
         page->saveTheme(themeDirectory);
     }
     mDesktopPage->saveTheme(themeDirectory);
