@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "editorpage.h"
 #include "editorwidget.h"
 
-#include <KZip>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KZip>
 #include <QTemporaryFile>
 
+#include <QDir>
 #include <QFile>
 #include <QTextStream>
-#include <QDir>
 
 using namespace GrantleeThemeEditor;
 
@@ -85,7 +85,9 @@ void EditorPage::saveAsFilename(const QString &filename)
     QFile file(filename);
     if (file.open(QIODevice::WriteOnly | QIODevice::Text)) {
         QTextStream out(&file);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         out.setCodec("UTF-8");
+#endif
         out << mEditor->toPlainText();
         file.close();
     } else {
@@ -100,8 +102,7 @@ void EditorPage::createZip(const QString &themeName, KZip *zip)
     saveAsFilename(tmp.fileName());
     const bool fileAdded = zip->addLocalFile(tmp.fileName(), themeName + QLatin1Char('/') + mPageFileName);
     if (!fileAdded) {
-        KMessageBox::error(this, i18n("Failed to add file into ZIP archive."),
-                           i18nc("@title:window", "Failed to add file"));
+        KMessageBox::error(this, i18n("Failed to add file into ZIP archive."), i18nc("@title:window", "Failed to add file"));
     }
 }
 
